@@ -36,6 +36,8 @@ Currently the constructs only support authentication via a [GitHub Personal Acce
 
 ## ActionSecret
 
+### TypeScript
+
 ```python
 import { ActionSecret } from 'cdk-github';
 
@@ -85,8 +87,6 @@ class ActionSecretStack(Stack):
         )
 ```
 
-Please note: the module name is `cdkgithub` and not `cdk-github`.
-
 ## ActionEnvironmentSecret
 
 ```python
